Changelog — ethz_snow 1.0.0 documentation

# Changelog

## Version 1.0

- Implementation of freezing model for the freezing stage in freeze-drying of a batch of vials on a shelf in python

- Currently supported features:

    - Simulation of the freezing process, i.e. of thermal evolution and of ice formation, for a batch with arbitrary number of vials

    - Arbitrary cooling protocols (i.e., user may choose cooling rate, integrate holding steps and controlled nucleation)

    - Tracking of nucleation times, nucleation temperatures and solidification times for all vials

    - Stochastic nucleation in the form of a Monte Carlo approach as well as controlled nucleation in the form of forced initiation of nucleation at a certain point

    - Cubic geometry of vial and rectangular arrangement on the shelf